@@ -28,8 +28,9 @@ NUMERIC_COLUMNS = [
 ]  # all numeric columns from fetched dataset
 
 # Constants used in Mixins
-MOVING_COLS = ["day", "close"]  # cols used for Moving indicator mixin
-KDJ_COLS = ["day", "close", "high", "low"]  # cols used for KDJ indicator mixin
+MOVING_COLS = ["day", "close"]  # cols used for Moving indicator mixin for `close`
+MOVING_VOLUMN_COLS = ["day", "volumn"]  # cols used for Moving indicator mixin for `volumn`
+HIGH_LOW_COLS = ["day", "close", "high", "low"]  # cols used for KDJ indicator mixin
 RSI_COLS = ["day", "close", "volumn"]  # cols used for RSI/VRSI indicator mixin
 
 # Constants used in StockInsider class
@@ -37,3 +38,4 @@ MA_N = [5, 10, 20, 60]  # Number of days counted for MA indicator
 MD_N = [5, 10, 20]  # Number of days counted for MD indicator
 EXPMA_N = [5, 10, 20, 60]  # Number of days counted for EMA indicator
 RSI_N = [6, 12, 24]  # Number of days counted for RSI/VRSI indicator
+MIKE_COLS = ["wr", "mr", "sr", "ws", "ms", "ss"]
